Security Advisories (1)
CVE-2022-1664 (2022-05-26)

Dpkg::Source::Archive in dpkg, the Debian package management system, before version 1.21.8, 1.20.10, 1.19.8, 1.18.26 is prone to a directory traversal vulnerability. When extracting untrusted source packages in v2 and v3 source package formats that include a debian.tar, the in-place extraction can lead to directory traversal situations on specially crafted orig.tar and debian.tar tarballs.

NAME

Dpkg::BuildProfiles - handle build profiles

DESCRIPTION

The Dpkg::BuildProfiles module provides functions to handle the build profiles.

FUNCTIONS

@profiles = get_build_profiles()

Get an array with the currently active build profiles, taken from the environment variable DEB_BUILD_PROFILES.

set_build_profiles(@profiles)

Set @profiles as the current active build profiles, by setting the environment variable DEB_BUILD_PROFILES.

@profiles = parse_build_profiles($string)

Parses a build profiles specification, into an array of array references.

evaluate_restriction_formula(\@formula, \@profiles)

Evaluate whether a restriction formula of the form "<foo bar> <baz>", given as a nested array, is true or false, given the array of enabled build profiles.

CHANGES

Version 1.00 (dpkg 1.17.17)

Mark the module as public.